@@ -1,4 +1,4 @@
-import core
+import .core
 # TODO figure out a way to make this more robust to python version changes
 
 
